@@ -42,7 +42,7 @@
 
 #ifndef lint
 static char copyright[] =
-"$Id: confpars.c,v 1.35 1996/09/13 18:58:20 mellon Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium.  All rights reserved.\n";
+"$Id: confpars.c,v 1.36.2.1 1997/03/29 08:06:44 mellon Exp $ Copyright (c) 1995, 1996 The Internet Software Consortium.  All rights reserved.\n";
 #endif /* not lint */
 
 #include "dhcpd.h"
@@ -289,7 +289,6 @@ int parse_statement (cfile, group, type, host_decl, declaration)
 		if (type == HOST_DECL)
 			parse_warn ("get-lease-hostnames not allowed here.");
 		group -> get_lease_hostnames = parse_boolean (cfile);
-note ("get_lease_hostnames: %d", group -> get_lease_hostnames);
 		break;
 
 	      case USE_HOST_DECL_NAMES:
@@ -609,7 +608,7 @@ void parse_class_declaration (cfile, group, type)
 	char *val;
 	int token;
 	struct class *class;
-	int declaration;
+	int declaration = 0;
 
 	token = next_token (&val, cfile);
 	if (token != STRING) {
@@ -866,13 +865,11 @@ void parse_hardware_param (cfile, hardware)
 	token = next_token (&val, cfile);
 	switch (token) {
 	      case ETHERNET:
-		hardware -> htype = ARPHRD_ETHER;
+		hardware -> htype = HTYPE_ETHER;
 		break;
-#ifdef ARPHRD_IEEE802 /* XXX */
 	      case TOKEN_RING:
-		hardware -> htype = ARPHRD_IEEE802;
+		hardware -> htype = HTYPE_IEEE802;
 		break;
-#endif
 	      default:
 		parse_warn ("expecting a network hardware type");
 		skip_to_semi (cfile);
@@ -1375,6 +1372,11 @@ struct lease *parse_lease_declaration (cfile)
 				lease.flags |= BOOTP_LEASE;
 				break;
 
+			      case ABANDONED:
+				seenbit = 256;
+				lease.flags |= ABANDONED_LEASE;
+				break;
+
 			      default:
 				skip_to_semi (cfile);
 				seenbit = 0;
